# Hermes Connector

The Hermes Connector package aims to create an abstraction layer between popular exchanges or brokers and quantitative finance scripts.

By defining standardised functions and return values that run and interpret the endpoints and routines of differnt APIs, it provides agnosticity for quantitative finance scripts, allowing the developer to quickly and seamlessly test and run their analyses across variety of platforms.


## Disclaimer

This is an on-going project with only one developer managing it. As of now, the code in this repository is not meant for production. Malfunctions and bugs are expected. Use this code at you own risk, the author of this code is not responsible for any damages or losses.

